#pragma semicolon 1

#include <ws_store>
#include <sourcemod>

public Plugin:myinfo = 
{
	name	= "STORE (Money)",
	author	= "wS (World-Source.Ru)",
	version = "1.3"
};

new g_CategoryID, g_ItemID; // ID категории и опции
new g_Price, g_Limit, g_Count[MAXPLAYERS + 1];

public OnPluginStart()
{
	// Создаем категории/опции с небольшой задержкой, чтобы быть уверенными что STORE готов
	CreateTimer(1.0, START);
}

public OnPluginEnd()
{
	// Удаляем категорию и опцию, которые мы создали
	// Но категорию удаляем только если в ней нет опций (пустая), т.к. другие модули могут её использовать

	if (g_CategoryID > 0 && !STORE_DeleteCategoryByID(g_CategoryID, true) && g_ItemID > 0)
		STORE_RemoveItemFromCategory(g_CategoryID, g_ItemID);
}

public STORE_Loaded()
{
	// STORE плагин только что включился, никаких категорий и опций еще нет, поэтому их снова нужно создавать.
	// Чтобы не рисковать добавить одну и ту же опцию несколько раз, мы просто перезагрузим плагин.

	g_CategoryID = 0; g_ItemID = 0;
	decl String:PluginName[150]; PluginName[0] = '\0'; GetPluginFilename(GetMyHandle(), PluginName, 150);
	ServerCommand("sm plugins reload \"%s\"", PluginName);
}

public Action:START(Handle:timer)
{
	// Здесь создаёте категории/опции
	/////////////////

	/////
	// Загружаем настройки из .txt файла
	new Handle:kv = CreateKeyValues("store_money");

	if (!FileToKeyValues(kv, "cfg/store/modules/store_money.txt"))
		SetFailState("Error in cfg/store/modules/store_money.txt");

	decl String:CategoryName[STORE_CATEGORY_LENGTH];
	KvGetString(kv, "CategoryName", CategoryName, STORE_CATEGORY_LENGTH);
	if (TrimString(CategoryName) < 1)
		SetFailState("Категория не указана");

	new bool:bCategoryExist = (g_CategoryID = STORE_GetCategoryID(CategoryName)) > 0;
	decl String:Text[STORE_ITEMTEXT_LENGTH], String:str_flag[10];

	// Если такой категории еще нет, то создаем её
	// STORE_CreateCategory можно использовать без всяких проверок, даже если категория уже существует
	// Но мы используем такой вариант, т.к. не знаем, будет ли добавлена опция в категорию, или же это будет пустая категория

	if (!bCategoryExist)
	{
		KvGetString(kv, "CategoryText", Text, STORE_ITEMTEXT_LENGTH);
		KvGetString(kv, "CategoryFlag", str_flag, 10);

		if ((g_CategoryID = STORE_CreateCategory(CategoryName, Text, str_flag)) < 1)
			SetFailState("Не удалось создать категорию '%s'", CategoryName);
	}

	// Добавляем опцию, если это нужно
	g_Price = KvGetNum(kv, "price");
	KvGetString(kv, "ItemText", Text, STORE_ITEMTEXT_LENGTH);
	if (TrimString(Text) > 0)
	{
		KvGetString(kv, "ItemFlag", str_flag, 10);
		if ((g_ItemID = STORE_AddItemToCategory(g_CategoryID, Text, g_Price, true, MyCallBack, str_flag)) < 1)
		{
			// wtf, опцию добавить не удалось, поэтому удаляем категорию, если она пустая
			if (!bCategoryExist)
			{
				STORE_DeleteCategoryByID(g_CategoryID, true);
				g_CategoryID = 0;
			}
			SetFailState("Не удалось добавить функцию '%s'", Text);
		}
	}

	// Если "ItemText" не указано, то "CategoryName" должно быть уникальным, чтобы только этот плагин использовал категорию
	else if (bCategoryExist)
		SetFailState("Укажите уникальное название категории или используйте ItemText");

	CloseHandle(kv);
	/////

	HookEvent("round_start", round_start, EventHookMode_PostNoCopy);
	return Plugin_Stop;
}


///


public MyCallBack(client, const String:steamid[], CategoryID, ItemID, ItemPrice)
{
	// Игрок выбрал опцию в категории

	if (ItemID == g_ItemID)
		wS_OnClientSelect(client, LastMenuItem:MI_InCategory);
}

public STORE_OnClientSelectEmptyCategory(client, const String:steamid[], CategoryID)
{
	// Игрок выбрал опцию в главном меню (пустую категорию)

	if (CategoryID == g_CategoryID)
		wS_OnClientSelect(client, LastMenuItem:MI_Main);
}

stock wS_OnClientSelect(client, LastMenuItem:MI)
{
	if (g_Limit > 0 && g_Count[client] >= g_Limit)
	{
		PrintCenterText(client, "Будет доступно в следующем раунде");
		STORE_ShowMenu(client, MI);
		return;
	}

	if (GetEntProp(client, Prop_Send, "m_iAccount") > 15999)
	{
		PrintCenterText(client, "У вас и так $16000");
		STORE_ShowMenu(client, MI);
		return;
	}

	if (g_Price > 0)
	{
		new credits = STORE_GetCredits(client);

		if (credits < g_Price)
		{
			PrintCenterText(client, "Вам не хватает %d кр", (g_Price - credits));
			STORE_ShowMenu(client, MI);
			return;
		}

		if (!STORE_SetCredits(client, (credits - g_Price)))
		{
			LogError("Не удалось установить кредиты игроку '%N'", client);
			return;
		}
	}

	g_Count[client]++;
	SetEntProp(client, Prop_Send, "m_iAccount", 16000);
	PrintToChat(client, "\x04Вам установлено $16000");

	STORE_ShowMenu(client, MI);
}


///


public round_start(Handle:event, const String:name[], bool:silent)
{
	for (new i = 1; i <= MaxClients; i++) g_Count[i] = 0;
}

public OnClientConnected(client)
{
	g_Count[client] = 0;
}